@@ -17,6 +17,9 @@
 
 #include "filterimporterthunderbird.h"
 #include "filter/mailfilter.h"
+#include <MailImporter/FilterSeaMonkey>
+#include <MailImporter/FilterIcedove>
+#include <MailImporter/FilterThunderbird>
 #include "mailcommon_debug.h"
 #include <QUrl>
 
@@ -55,19 +58,22 @@ void FilterImporterThunderbird::readStream(QTextStream &stream)
     appendFilter(filter);
 }
 
+QString FilterImporterThunderbird::defaultSeaMonkeyFiltersSettingsPath()
+{
+    return MailImporter::FilterSeaMonkey::defaultSettingsPath();
+}
+
 QString FilterImporterThunderbird::defaultIcedoveFiltersSettingsPath()
 {
-    return QStringLiteral("%1/.icedove/").arg(QDir::homePath());
+    return MailImporter::FilterIcedove::defaultSettingsPath();
 }
 
 QString FilterImporterThunderbird::defaultThunderbirdFiltersSettingsPath()
 {
-    return QStringLiteral("%1/.thunderbird/").arg(QDir::homePath());
+    return MailImporter::FilterThunderbird::defaultSettingsPath();
 }
 
-MailCommon::MailFilter *FilterImporterThunderbird::parseLine(QTextStream &stream,
-        QString line,
-        MailCommon::MailFilter *filter)
+MailCommon::MailFilter *FilterImporterThunderbird::parseLine(QTextStream &stream, QString line, MailCommon::MailFilter *filter)
 {
     if (line.startsWith(QStringLiteral("name="))) {
         appendFilter(filter);
@@ -150,8 +156,7 @@ MailCommon::MailFilter *FilterImporterThunderbird::parseLine(QTextStream &stream
     return filter;
 }
 
-void FilterImporterThunderbird::extractConditions(const QString &line,
-        MailCommon::MailFilter *filter)
+void FilterImporterThunderbird::extractConditions(const QString &line, MailCommon::MailFilter *filter)
 {
     if (line.startsWith(QStringLiteral("AND"))) {
         filter->pattern()->setOp(SearchPattern::OpAnd);
@@ -178,8 +183,7 @@ void FilterImporterThunderbird::extractConditions(const QString &line,
     }
 }
 
-bool FilterImporterThunderbird::splitConditions(const QString &cond,
-        MailCommon::MailFilter *filter)
+bool FilterImporterThunderbird::splitConditions(const QString &cond, MailCommon::MailFilter *filter)
 {
     /*
     *    {nsMsgSearchAttrib::Subject,    "subject"},
@@ -360,9 +364,7 @@ bool FilterImporterThunderbird::splitConditions(const QString &cond,
     return true;
 }
 
-QString FilterImporterThunderbird::extractActions(const QString &line,
-        MailCommon::MailFilter *filter,
-        QString &value)
+QString FilterImporterThunderbird::extractActions(const QString &line, MailCommon::MailFilter *filter, QString &value)
 {
     /*
     { nsMsgFilterAction::MoveToFolder,            "Move to folder"},
